package com.gprinter.utils;

import android.graphics.Bitmap;

/* loaded from: com_gprinter_utils.jar:com/gprinter/utils/BMPConverterUtil.class */
public class BMPConverterUtil {
    public static final int PALETTE_BW = 0;
    public static final int PALETTE_BWR = 1;
    public static final int PALETTE_BWY = 2;

    public static RGBTriple[] getPalette(int deviceType) {
        RGBTriple[] palette;
        if (deviceType == 1) {
            palette = new RGBTriple[]{new RGBTriple(0, 0, 0), new RGBTriple(255, 255, 255), new RGBTriple(255, 0, 0)};
        } else if (deviceType == 2) {
            palette = new RGBTriple[]{new RGBTriple(0, 0, 0), new RGBTriple(255, 255, 255), new RGBTriple(255, 255, 0)};
        } else {
            palette = new RGBTriple[]{new RGBTriple(0, 0, 0), new RGBTriple(255, 255, 255)};
        }
        return palette;
    }

    public static byte[][] floydSteinbergDither(RGBTriple[][] image, RGBTriple[] palette) {
        byte[][] result = new byte[image.length][image[0].length];
        for (int y = 0; y < image.length; y++) {
            for (int x = 0; x < image[y].length; x++) {
                RGBTriple currentPixel = image[y][x];
                byte index = findNearestColor(currentPixel, palette);
                result[y][x] = index;
                for (int i = 0; i < 3; i++) {
                    int error = (currentPixel.channels[i] & 255) - (palette[index].channels[i] & 255);
                    if (x + 1 < image[0].length) {
                        image[y][x + 1].channels[i] = plus_truncate_uchar(image[y][x + 1].channels[i], (error * 7) >> 4);
                    }
                    if (y + 1 < image.length) {
                        if (x - 1 > 0) {
                            image[y + 1][x - 1].channels[i] = plus_truncate_uchar(image[y + 1][x - 1].channels[i], (error * 3) >> 4);
                        }
                        image[y + 1][x].channels[i] = plus_truncate_uchar(image[y + 1][x].channels[i], (error * 5) >> 4);
                        if (x + 1 < image[0].length) {
                            image[y + 1][x + 1].channels[i] = plus_truncate_uchar(image[y + 1][x + 1].channels[i], error >> 4);
                        }
                    }
                }
            }
        }
        return result;
    }

    public static Bitmap floydSteinberg(Bitmap bufferedImage, int deviceType) {
        int width = bufferedImage.getWidth();
        int height = bufferedImage.getHeight();
        RGBTriple[][] image = new RGBTriple[width][height];
        for (int i = 0; i < width; i++) {
            for (int j = 0; j < height; j++) {
                int pixel = bufferedImage.getPixel(i, j);
                int rx = (pixel & 16711680) >> 16;
                int gx = (pixel & 65280) >> 8;
                int bx = pixel & 255;
                RGBTriple rgbTriple = new RGBTriple(rx, gx, bx);
                image[i][j] = rgbTriple;
            }
        }
        Bitmap newBufferedImage = Bitmap.createBitmap(width, height, bufferedImage.getConfig());
        byte[][] to = floydSteinbergDither(image, getPalette(deviceType));
        for (int i2 = 0; i2 < to.length; i2++) {
            for (int j2 = 0; j2 < to[i2].length; j2++) {
                if (to[i2][j2] == 0) {
                    newBufferedImage.setPixel(i2, j2, 0 | (-16777216));
                } else if (to[i2][j2] == 1) {
                    newBufferedImage.setPixel(i2, j2, 16777215 | (-16777216));
                } else if (to[i2][j2] == 2 && deviceType == 1) {
                    newBufferedImage.setPixel(i2, j2, 16711680 | (-16777216));
                } else if (to[i2][j2] == 2 && deviceType == 2) {
                    newBufferedImage.setPixel(i2, j2, 16776960 | (-16777216));
                }
            }
        }
        return newBufferedImage;
    }

    private static byte plus_truncate_uchar(byte a, int b) {
        if ((a & 255) + b < 0) {
            return (byte) 0;
        }
        if ((a & 255) + b > 255) {
            return (byte) -1;
        }
        return (byte) (a + b);
    }

    private static byte findNearestColor(RGBTriple color, RGBTriple[] palette) {
        int minDistanceSquared = 195076;
        byte bestIndex = 0;
        byte b = 0;
        while (true) {
            byte i = b;
            if (i < palette.length) {
                int Rdiff = (color.channels[0] & 255) - (palette[i].channels[0] & 255);
                int Gdiff = (color.channels[1] & 255) - (palette[i].channels[1] & 255);
                int Bdiff = (color.channels[2] & 255) - (palette[i].channels[2] & 255);
                int distanceSquared = (Rdiff * Rdiff) + (Gdiff * Gdiff) + (Bdiff * Bdiff);
                if (distanceSquared < minDistanceSquared) {
                    minDistanceSquared = distanceSquared;
                    bestIndex = i;
                }
                b = (byte) (i + 1);
            } else {
                return bestIndex;
            }
        }
    }

    /* loaded from: com_gprinter_utils.jar:com/gprinter/utils/BMPConverterUtil$RGBTriple.class */
    public static class RGBTriple {
        public final byte[] channels;

        public RGBTriple(int R, int G, int B) {
            this.channels = new byte[]{(byte) R, (byte) G, (byte) B};
        }
    }
}
